@@ -23,7 +23,7 @@ using namespace QtMobility;
 
 static const char* KEYPAD_IDX_PROPERTY = "keypadidx";
 
-static const unsigned int CACHE_VERSION = 11;
+static const unsigned int CACHE_VERSION = 12;
 
 static const int MAX_NAME_SIZE = 30 /*pt*/;
 
@@ -309,7 +309,7 @@ void k9call::populateList()
 	// Then load from cache
 	if(!loadCache()) {
 		qDebug("Load Cache failed, requesting new list of contacts");
-		emit syncContacts();
+		syncContacts();
 	}
 
 	// Clear the search string
@@ -332,7 +332,7 @@ void k9call::makeDbusGSMCall(QString number)
     );
     msg << number;
     msg << 0;
-    msg = QDBusConnection::systemBus().call(msg, QDBus::BlockWithGui);
+    msg = QDBusConnection::systemBus().call(msg);
 	
 	if(msg.type() == QDBusMessage::ErrorMessage) {
 		QErrorMessage* err = new QErrorMessage();
@@ -430,6 +430,7 @@ void k9call::syncContacts()
 
 void k9call::updateContacts(QList<QContact> contacts) 
 {
+	qDebug() << "Got update contacts call!";
 	// Delete the Contacts Thread Worker
 	m_ContactWorker->quit();
 	m_ContactWorker->wait();
